@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: stock.cc,v 1.3 2004/04/11 21:00:53 murrayc Exp $ */
+/* $Id: stock.cc,v 1.4 2005/01/06 22:51:46 mxpxpod Exp $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -41,6 +41,7 @@ const Gtk::BuiltinStockID DIALOG_ERROR = { GTK_STOCK_DIALOG_ERROR };
 const Gtk::BuiltinStockID DIALOG_QUESTION  = { GTK_STOCK_DIALOG_QUESTION };
 const Gtk::BuiltinStockID DND = { GTK_STOCK_DND };
 const Gtk::BuiltinStockID DND_MULTIPLE = { GTK_STOCK_DND_MULTIPLE };
+const Gtk::BuiltinStockID ABOUT = { GTK_STOCK_ABOUT };
 const Gtk::BuiltinStockID ADD = { GTK_STOCK_ADD };
 const Gtk::BuiltinStockID APPLY= { GTK_STOCK_APPLY };
 const Gtk::BuiltinStockID BOLD= { GTK_STOCK_BOLD };
@@ -48,11 +49,17 @@ const Gtk::BuiltinStockID CANCEL = { GTK_STOCK_CANCEL };
 const Gtk::BuiltinStockID CDROM = { GTK_STOCK_CDROM };
 const Gtk::BuiltinStockID CLEAR = { GTK_STOCK_CLEAR };
 const Gtk::BuiltinStockID CLOSE = { GTK_STOCK_CLOSE };
+const Gtk::BuiltinStockID COLOR_PICKER = { GTK_STOCK_COLOR_PICKER };
 const Gtk::BuiltinStockID CONVERT = { GTK_STOCK_CONVERT };
+const Gtk::BuiltinStockID CONNECT = { GTK_STOCK_CONNECT };
 const Gtk::BuiltinStockID COPY = { GTK_STOCK_COPY };
 const Gtk::BuiltinStockID CUT = { GTK_STOCK_CUT };
 const Gtk::BuiltinStockID DELETE = { GTK_STOCK_DELETE };
+const Gtk::BuiltinStockID DIRECTORY = { GTK_STOCK_DIRECTORY };
+const Gtk::BuiltinStockID DISCONNECT = { GTK_STOCK_DISCONNECT };
+const Gtk::BuiltinStockID EDIT = { GTK_STOCK_EDIT };
 const Gtk::BuiltinStockID EXECUTE = { GTK_STOCK_EXECUTE };
+const Gtk::BuiltinStockID FILE = { GTK_STOCK_FILE };
 const Gtk::BuiltinStockID FIND = { GTK_STOCK_FIND };
 const Gtk::BuiltinStockID FIND_AND_REPLACE = { GTK_STOCK_FIND_AND_REPLACE };
 const Gtk::BuiltinStockID FLOPPY = { GTK_STOCK_FLOPPY };
@@ -64,9 +71,12 @@ const Gtk::BuiltinStockID GO_BACK = { GTK_STOCK_GO_BACK };
 const Gtk::BuiltinStockID GO_DOWN = { GTK_STOCK_GO_DOWN };
 const Gtk::BuiltinStockID GO_FORWARD = { GTK_STOCK_GO_FORWARD };
 const Gtk::BuiltinStockID GO_UP = { GTK_STOCK_GO_UP };
+const Gtk::BuiltinStockID HARDDISK = { GTK_STOCK_HARDDISK };
 const Gtk::BuiltinStockID HELP = { GTK_STOCK_HELP };
 const Gtk::BuiltinStockID HOME = { GTK_STOCK_HOME };
 const Gtk::BuiltinStockID INDEX = { GTK_STOCK_INDEX };
+const Gtk::BuiltinStockID INDENT = { GTK_STOCK_INDENT };
+const Gtk::BuiltinStockID UNINDENT = { GTK_STOCK_UNINDENT };
 const Gtk::BuiltinStockID ITALIC = { GTK_STOCK_ITALIC };
 const Gtk::BuiltinStockID JUMP_TO = { GTK_STOCK_JUMP_TO };
 const Gtk::BuiltinStockID JUSTIFY_CENTER = { GTK_STOCK_JUSTIFY_CENTER };
@@ -74,6 +84,15 @@ const Gtk::BuiltinStockID JUSTIFY_FILL = { GTK_STOCK_JUSTIFY_FILL };
 const Gtk::BuiltinStockID JUSTIFY_LEFT = { GTK_STOCK_JUSTIFY_LEFT };
 const Gtk::BuiltinStockID JUSTIFY_RIGHT = { GTK_STOCK_JUSTIFY_RIGHT };
 const Gtk::BuiltinStockID MISSING_IMAGE = { GTK_STOCK_MISSING_IMAGE };
+const Gtk::BuiltinStockID MEDIA_FORWARD = { GTK_STOCK_MEDIA_FORWARD };
+const Gtk::BuiltinStockID MEDIA_NEXT = { GTK_STOCK_MEDIA_NEXT };
+const Gtk::BuiltinStockID MEDIA_PAUSE = { GTK_STOCK_MEDIA_PAUSE };
+const Gtk::BuiltinStockID MEDIA_PLAY = { GTK_STOCK_MEDIA_PLAY };
+const Gtk::BuiltinStockID MEDIA_PREVIOUS = { GTK_STOCK_MEDIA_PREVIOUS };
+const Gtk::BuiltinStockID MEDIA_RECORD = { GTK_STOCK_MEDIA_RECORD };
+const Gtk::BuiltinStockID MEDIA_REWIND = { GTK_STOCK_MEDIA_REWIND };
+const Gtk::BuiltinStockID MEDIA_STOP = { GTK_STOCK_MEDIA_STOP };
+const Gtk::BuiltinStockID NETWORK = { GTK_STOCK_NETWORK };
 const Gtk::BuiltinStockID NEW = { GTK_STOCK_NEW };
 const Gtk::BuiltinStockID NO = { GTK_STOCK_NO };
 const Gtk::BuiltinStockID OK = { GTK_STOCK_OK };
